@@ -80,7 +80,7 @@ public:
      * for more information.
      * @param visitor the visitor calling the method
      */
-    bool accept(DocumentVisitor *visitor) Q_DECL_OVERRIDE;
+    bool accept(DocumentVisitor *visitor) override;
 
     /**
      * a list of persons who are the authors of this feed.
@@ -184,14 +184,14 @@ public:
      *
      * @return debug string
      */
-    QString debugInfo() const Q_DECL_OVERRIDE;
+    QString debugInfo() const override;
 
     /**
      * returns whether this document is valid or not.
      * Invalid documents do not contain any useful
      * information.
      */
-    bool isValid() const Q_DECL_OVERRIDE;
+    bool isValid() const override;
 };
 
 /**
@@ -223,7 +223,7 @@ public:
      * for more information.
      * @param visitor the visitor calling the method
      */
-    bool accept(DocumentVisitor *visitor) Q_DECL_OVERRIDE;
+    bool accept(DocumentVisitor *visitor) override;
 
     /**
      * returns the single entry described in the source.
@@ -238,14 +238,14 @@ public:
      *
      * @return debug string
      */
-    QString debugInfo() const Q_DECL_OVERRIDE;
+    QString debugInfo() const override;
 
     /**
      * returns whether this document is valid or not.
      * Invalid documents do not contain any useful
      * information.
      */
-    bool isValid() const Q_DECL_OVERRIDE;
+    bool isValid() const override;
 };
 
 } // namespace Atom
