@@ -26,7 +26,7 @@
 #include <syndication/elementwrapper.h>
 #include <syndication/specificitem.h>
 
-#include <QtCore/QList>
+#include <QList>
 
 #include <ctime>
 
@@ -75,7 +75,7 @@ public:
      * @param visitor the visitor calling the method
      */
 
-    bool accept(SpecificItemVisitor *visitor) Q_DECL_OVERRIDE;
+    bool accept(SpecificItemVisitor *visitor) override;
 
     /**
      * list of persons who are authors of this entry. (required)
